==> open-xchange-subscribe_7.0.0.orig.tar.bz2: open-xchange-subscribe-7.0.0/com.openexchange.subscribe.microformats/src/com/openexchange/subscribe/microformats/OXMFErrorStrings.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.microformats;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link OXMFErrorStrings}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class OXMFErrorStrings implements LocalizableStrings{

    // A parsing error occurred: %1$s.
    public static final String PARSE_EXCEPTION = "A parsing error occurred: %1$s.";
    public static final String PARSE_EXCEPTION_HELP = "Provide well-formed HTML.";

    // An IOException occurred: %1$s. Was trying to get the service at %2$s.
    public static final String IOException = "An IOException occurred: %1$s. Was trying to get the service at %2$s.";
    public static final String IOException_HELP = "Try again later.";

    // A HTTPException occurred: %1$s. Was trying to get the service at %2$s.
    public static final String HttpException = "A HTTPException occurred: %1$s. Was trying to get the service at %2$s.";
    public static final String HttpException_HELP = "Try again later.";

    // Can only post to external subscription sources.
    public static final String CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES = "Can only post to external subscription sources.";
    public static final String CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES_HELP = "Try again later.";

    // Could not fetch site at %1$s. Please check the spelling or whether you can reach the site in your browser.
    public static final String ERROR_LOADING_SUBSCRIPTION = "Could not fetch site at %1$s. Please check the spelling or whether you can reach the site in your browser.";
    public static final String ERROR_LOADING_SUBSCRIPTION_HELP = "Try again later.";

}

==> open-xchange-subscribe_7.2.0.orig.tar.bz2: open-xchange-subscribe-7.2.0/com.openexchange.subscribe.microformats/src/com/openexchange/subscribe/microformats/OXMFErrorStrings.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.microformats;

import com.openexchange.i18n.LocalizableStrings;

/**
 * {@link OXMFErrorStrings}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class OXMFErrorStrings implements LocalizableStrings{

    // A parsing error occurred: %1$s.
    public static final String PARSE_EXCEPTION = "A parsing error occurred: %1$s.";
    public static final String PARSE_EXCEPTION_HELP = "Provide well-formed HTML.";

    // An IOException occurred: %1$s. Was trying to get the service at %2$s.
    public static final String IOException = "An IOException occurred: %1$s. Was trying to get the service at %2$s.";
    public static final String IOException_HELP = "Try again later.";

    // A HTTPException occurred: %1$s. Was trying to get the service at %2$s.
    public static final String HttpException = "A HTTPException occurred: %1$s. Was trying to get the service at %2$s.";
    public static final String HttpException_HELP = "Try again later.";

    // Can only post to external subscription sources.
    public static final String CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES = "Can only post to external subscription sources.";
    public static final String CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES_HELP = "Try again later.";

    // Could not fetch site at %1$s. Please check the spelling or whether you can reach the site in your browser.
    public static final String ERROR_LOADING_SUBSCRIPTION = "Could not fetch site at %1$s. Please check the spelling or whether you can reach the site in your browser.";
    public static final String ERROR_LOADING_SUBSCRIPTION_HELP = "Try again later.";

    // The string cannot be parsed to a valid URL.
    public static final String INVALID_URL = "The string cannot be parsed to a valid URL.";

}
